package com.mcwl.web.controller.communityCenter;

import com.mcwl.common.core.controller.BaseController;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.communityCenter.domain.dto.CommentRes;
import com.mcwl.communityCenter.domain.vo.PublicModelCommentVo;
import com.mcwl.communityCenter.domain.PublishComment;
import com.mcwl.communityCenter.service.PublishCommentService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 社群评论
 */
@Api(tags = "社群评论")
@RequestMapping("publishComment")
@RestController
@RequiredArgsConstructor

public class PublishCommentController extends BaseController {

    private final PublishCommentService publishCommentService;


    /**
     * 添加评论
     *
     * @param commentRes 评论请求参数
     * @return
     */
    @ApiOperation(value = "添加评论")
    @PostMapping("/save")
    public AjaxResult save(@RequestBody @Valid CommentRes commentRes) {

        return publishCommentService.addComment(commentRes);
    }


    /**
     * 获取评论
     *
     * @param publishComment
     * @return
     */
    @ApiOperation(value = "获取评论")
    @GetMapping("/comment/{Id}")
    public List<PublicModelCommentVo> getComment(@RequestBody PublishComment publishComment) {

        return publishCommentService.getComment(publishComment);
    }


    /**
     * 点赞或取消点赞评论
     *
     * @param userId    用户ID
     * @param commentId 评论ID
     * @return 更新后的点赞数
     */
    @ApiOperation(value = "点赞或取消点赞评论")
    @PostMapping("/{commentId}/like")
    public ResponseEntity<Integer> toggleLike(@PathVariable Long commentId, @RequestParam Long userId) {
        int updatedLikes = publishCommentService.toggleLike(userId, commentId);
        return ResponseEntity.ok(updatedLikes);
    }


    @ApiOperation(value = "删除评论")
    @DeleteMapping("/{id}")
    public ResponseEntity<String> delete(@PathVariable Long id) {
        publishCommentService.removeById(id);
        return ResponseEntity.ok("删除成功");
    }

}
